# Alya's types
Using [ark0f's api parser](https://github.com/ark0f/tg-bot-api).


## Generate
1. Clone this repo.

    ```git clone https://github.com/mrsmori/alya-types```

2. Create venv

    ```py -m venv env```

3. Generate models
    ```py main.py```

## Using

1. Install
    ```pip install types-alya```

2. Use
    ```python 
    from types_alya import ApiWrapper, objects
    ```